@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "archivemailwidget.h"
@@ -114,8 +101,7 @@ ArchiveMailWidget::ArchiveMailWidget(const KSharedConfigPtr &config, QWidget *pa
 }
 
 ArchiveMailWidget::~ArchiveMailWidget()
-{
-}
+= default;
 
 void ArchiveMailWidget::slotCustomContextMenuRequested(const QPoint &)
 {
@@ -163,7 +149,7 @@ void ArchiveMailWidget::load()
     const int numberOfCollection = collectionList.count();
     for (int i = 0; i < numberOfCollection; ++i) {
         KConfigGroup collectionGroup = config()->group(collectionList.at(i));
-        ArchiveMailInfo *info = new ArchiveMailInfo(collectionGroup);
+        auto *info = new ArchiveMailInfo(collectionGroup);
         if (info->isValid()) {
             createOrUpdateItem(info);
         } else {
@@ -220,7 +206,7 @@ bool ArchiveMailWidget::save() const
 
     const int numberOfItem(mWidget.treeWidget->topLevelItemCount());
     for (int i = 0; i < numberOfItem; ++i) {
-        ArchiveMailItem *mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
+        auto *mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
         if (mailItem->info()) {
             KConfigGroup group = config()->group(ArchiveMailAgentUtil::archivePattern.arg(mailItem->info()->saveCollectionId()));
             mailItem->info()->writeConfig(group);
@@ -255,7 +241,7 @@ void ArchiveMailWidget::slotModifyItem()
         if (!item) {
             return;
         }
-        ArchiveMailItem *archiveItem = static_cast<ArchiveMailItem *>(item);
+        auto *archiveItem = static_cast<ArchiveMailItem *>(item);
         QPointer<AddArchiveMailDialog> dialog = new AddArchiveMailDialog(archiveItem->info(), parentWidget());
         if (dialog->exec()) {
             ArchiveMailInfo *info = dialog->info();
@@ -287,7 +273,7 @@ bool ArchiveMailWidget::verifyExistingArchive(ArchiveMailInfo *info) const
 {
     const int numberOfItem(mWidget.treeWidget->topLevelItemCount());
     for (int i = 0; i < numberOfItem; ++i) {
-        ArchiveMailItem *mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
+        auto *mailItem = static_cast<ArchiveMailItem *>(mWidget.treeWidget->topLevelItem(i));
         ArchiveMailInfo *archiveItemInfo = mailItem->info();
         if (archiveItemInfo) {
             if (info->saveCollectionId() == archiveItemInfo->saveCollectionId()) {
@@ -306,11 +292,11 @@ void ArchiveMailWidget::slotOpenFolder()
         if (!item) {
             return;
         }
-        ArchiveMailItem *archiveItem = static_cast<ArchiveMailItem *>(item);
+        auto *archiveItem = static_cast<ArchiveMailItem *>(item);
         ArchiveMailInfo *archiveItemInfo = archiveItem->info();
         if (archiveItemInfo) {
             const QUrl url = archiveItemInfo->url();
-            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
+            auto *job = new KIO::OpenUrlJob(url);
             job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, parentWidget()));
             job->setRunExecutables(false);
             job->start();
@@ -321,7 +307,7 @@ void ArchiveMailWidget::slotOpenFolder()
 void ArchiveMailWidget::slotItemChanged(QTreeWidgetItem *item, int col)
 {
     if (item) {
-        ArchiveMailItem *archiveItem = static_cast<ArchiveMailItem *>(item);
+        auto *archiveItem = static_cast<ArchiveMailItem *>(item);
         if (archiveItem->info()) {
             if (col == ArchiveMailWidget::Name) {
                 archiveItem->info()->setEnabled(archiveItem->checkState(ArchiveMailWidget::Name) == Qt::Checked);
