@@ -1,27 +1,13 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "followupreminderfinishtaskjob.h"
 #include "followupreminderinfo.h"
 #include "followupreminderagent_debug.h"
 
-#include <AkonadiCore/Item>
 #include <AkonadiCore/ItemFetchJob>
 #include <AkonadiCore/ItemModifyJob>
 #include <KCalendarCore/Todo>
@@ -33,8 +19,7 @@ FollowUpReminderFinishTaskJob::FollowUpReminderFinishTaskJob(Akonadi::Item::Id i
 }
 
 FollowUpReminderFinishTaskJob::~FollowUpReminderFinishTaskJob()
-{
-}
+= default;
 
 void FollowUpReminderFinishTaskJob::start()
 {
@@ -50,7 +35,7 @@ void FollowUpReminderFinishTaskJob::start()
 void FollowUpReminderFinishTaskJob::closeTodo()
 {
     Akonadi::Item item(mTodoId);
-    Akonadi::ItemFetchJob *job = new Akonadi::ItemFetchJob(item, this);
+    auto *job = new Akonadi::ItemFetchJob(item, this);
     connect(job, &Akonadi::ItemFetchJob::result, this, &FollowUpReminderFinishTaskJob::slotItemFetchJobDone);
 }
 
@@ -77,7 +62,7 @@ void FollowUpReminderFinishTaskJob::slotItemFetchJobDone(KJob *job)
         Akonadi::Item updateItem = item;
         updateItem.setPayload<KCalendarCore::Todo::Ptr>(todo);
 
-        Akonadi::ItemModifyJob *job = new Akonadi::ItemModifyJob(updateItem);
+        auto *job = new Akonadi::ItemModifyJob(updateItem);
         connect(job, &Akonadi::ItemModifyJob::result, this, &FollowUpReminderFinishTaskJob::slotItemModifiedResult);
     } else {
         qCWarning(FOLLOWUPREMINDERAGENT_LOG) << " Found item different from 1: " << lst.count();
