@@ -1,20 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 #include "potentialphishingdetailwidget.h"
@@ -28,21 +15,20 @@
 
 PotentialPhishingDetailWidget::PotentialPhishingDetailWidget(QWidget *parent)
     : QWidget(parent)
+    , mListWidget(new QListWidget(this))
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setContentsMargins(0, 0, 0, 0);
+    auto *mainLayout = new QVBoxLayout(this);
+    mainLayout->setContentsMargins({});
     QLabel *lab = new QLabel(i18n("Select email to put in whitelist:"), this);
     lab->setObjectName(QStringLiteral("label"));
     mainLayout->addWidget(lab);
 
-    mListWidget = new QListWidget(this);
     mListWidget->setObjectName(QStringLiteral("list_widget"));
     mainLayout->addWidget(mListWidget);
 }
 
 PotentialPhishingDetailWidget::~PotentialPhishingDetailWidget()
-{
-}
+= default;
 
 void PotentialPhishingDetailWidget::fillList(const QStringList &lst)
 {
@@ -50,7 +36,7 @@ void PotentialPhishingDetailWidget::fillList(const QStringList &lst)
     QStringList emailsAdded;
     for (const QString &mail : lst) {
         if (!emailsAdded.contains(mail)) {
-            QListWidgetItem *item = new QListWidgetItem(mListWidget);
+            auto *item = new QListWidgetItem(mListWidget);
             item->setCheckState(Qt::Unchecked);
             item->setText(mail);
             emailsAdded << mail;
