@@ -1,23 +1,11 @@
 /*
  * This file is part of KMail.
  *
- * Copyright (c) 2010 KDAB
+ * SPDX-FileCopyrightText: 2010 KDAB
  *
- * Author: Tobias Koenig <tokoe@kde.org>
+ * SPDX-FileContributor: Tobias Koenig <tokoe@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include "addressvalidationjob.h"
@@ -39,8 +27,7 @@ AddressValidationJob::AddressValidationJob(const QString &emailAddresses, QWidge
 }
 
 AddressValidationJob::~AddressValidationJob()
-{
-}
+= default;
 
 void AddressValidationJob::setDefaultDomain(const QString &domainName)
 {
@@ -49,7 +36,7 @@ void AddressValidationJob::setDefaultDomain(const QString &domainName)
 
 void AddressValidationJob::start()
 {
-    AliasesExpandJob *job = new AliasesExpandJob(mEmailAddresses, mDomainDefaultName, this);
+    auto *job = new AliasesExpandJob(mEmailAddresses, mDomainDefaultName, this);
     connect(job, &AliasesExpandJob::result, this, &AddressValidationJob::slotAliasExpansionDone);
     job->start();
 }
