@@ -1,21 +1,10 @@
 /*
   This file is part of KMail, the KDE mail client.
-  Copyright (c) 2002 Don Sanders <sanders@kde.org>
+  SPDX-FileCopyrightText: 2002 Don Sanders <sanders@kde.org>
 
   Based on the work of Stefan Taferner <taferner@kde.org>
 
-  KMail is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  KMail is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #ifndef KMAIL_KMMAINWIDGET
@@ -99,7 +88,7 @@ class KMAIL_EXPORT KMMainWidget : public QWidget
     Q_OBJECT
 
 public:
-    typedef QList<KMMainWidget *> PtrList;
+    using PtrList = QList<KMMainWidget *>;
 
     KMMainWidget(QWidget *parent, KXMLGUIClient *aGUIClient, KActionCollection *actionCollection, const KSharedConfig::Ptr &config = KMKernel::self()->config());
     ~KMMainWidget() override;
@@ -528,7 +517,6 @@ private:
     void slotRestartAccount();
     void slotAccountSettings();
     void updateDisplayFormatMessage();
-    void slotContactHtmlPreferencesUpdated(const Akonadi::Item &contact, Akonadi::Item::Id id, bool showAsHTML, bool remoteContent);
 
     // Message actions
     QAction *mDeleteAction = nullptr;
@@ -639,8 +627,8 @@ private:
     DisplayMessageFormatActionMenu *mDisplayMessageFormatMenu = nullptr;
     MessageViewer::Viewer::DisplayFormatMessage mFolderDisplayFormatPreference = MessageViewer::Viewer::UseGlobalSetting;
     QAction *mSearchMessages = nullptr;
-    KMLaunchExternalComponent *mLaunchExternalComponent = nullptr;
-    ManageShowCollectionProperties *mManageShowCollectionProperties = nullptr;
+    KMLaunchExternalComponent *const mLaunchExternalComponent;
+    ManageShowCollectionProperties *const mManageShowCollectionProperties;
     QAction *mShowIntroductionAction = nullptr;
     QAction *mMarkAllMessageAsReadAndInAllSubFolder = nullptr;
     KActionMenuAccount *mAccountActionMenu = nullptr;
