@@ -1,20 +1,8 @@
 /*
  * kmail: KDE mail client
- * Copyright (c) 1996-1998 Stefan Taferner <taferner@kde.org>
+ * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -48,8 +36,6 @@ class KMailApplication : public KontactInterface::PimUniqueApplication
 public:
     KMailApplication(int &argc, char **argv[])
         : KontactInterface::PimUniqueApplication(argc, argv)
-        , mDelayedInstanceCreation(false)
-        , mEventLoopReached(false)
     {
     }
 
@@ -62,8 +48,8 @@ public Q_SLOTS:
     int newInstance(const QByteArray &startupId, const QStringList &arguments, const QString &workingDirectory) override;
 
 protected:
-    bool mDelayedInstanceCreation;
-    bool mEventLoopReached;
+    bool mDelayedInstanceCreation = false;
+    bool mEventLoopReached = false;
 };
 
 void KMailApplication::commitData(QSessionManager &)
@@ -149,7 +135,7 @@ int main(int argc, char *argv[])
 
 #ifdef WITH_KUSERFEEDBACK
     if (cmdArgs->isSet(QStringLiteral("feedback"))) {
-        KMailUserFeedbackProvider *userFeedback = new KMailUserFeedbackProvider(nullptr);
+        auto *userFeedback = new KMailUserFeedbackProvider(nullptr);
         QTextStream(stdout) << userFeedback->describeDataSources() << '\n';
         delete userFeedback;
         return 0;
