@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "manageshowcollectionproperties.h"
@@ -36,22 +23,21 @@ Q_DECLARE_METATYPE(QPointer<KPIM::ProgressItem>)
 ManageShowCollectionProperties::ManageShowCollectionProperties(KMMainWidget *mainWidget, QObject *parent)
     : QObject(parent)
     , mMainWidget(mainWidget)
+    , mPages({QStringLiteral("MailCommon::CollectionGeneralPage")
+              , QStringLiteral("KMail::CollectionViewPage")
+              , QStringLiteral("Akonadi::CachePolicyPage")
+              , QStringLiteral("KMail::CollectionTemplatesPage")
+              , QStringLiteral("MailCommon::CollectionExpiryPage")
+              , QStringLiteral("PimCommon::CollectionAclPage")
+              , QStringLiteral("KMail::CollectionMailingListPage")
+              , QStringLiteral("KMail::CollectionQuotaPage")
+              , QStringLiteral("KMail::CollectionShortcutPage")
+              , QStringLiteral("Akonadi::CollectionMaintenancePage")})
 {
-    mPages = QStringList() << QStringLiteral("MailCommon::CollectionGeneralPage")
-                           << QStringLiteral("KMail::CollectionViewPage")
-                           << QStringLiteral("Akonadi::CachePolicyPage")
-                           << QStringLiteral("KMail::CollectionTemplatesPage")
-                           << QStringLiteral("MailCommon::CollectionExpiryPage")
-                           << QStringLiteral("PimCommon::CollectionAclPage")
-                           << QStringLiteral("KMail::CollectionMailingListPage")
-                           << QStringLiteral("KMail::CollectionQuotaPage")
-                           << QStringLiteral("KMail::CollectionShortcutPage")
-                           << QStringLiteral("Akonadi::CollectionMaintenancePage");
 }
 
 ManageShowCollectionProperties::~ManageShowCollectionProperties()
-{
-}
+= default;
 
 void ManageShowCollectionProperties::slotCollectionProperties()
 {
@@ -99,7 +85,7 @@ void ManageShowCollectionProperties::showCollectionProperties(const QString &pag
             progressItem->setUsesBusyIndicator(true);
             progressItem->setCryptoStatus(KPIM::ProgressItem::Unknown);
 
-            Akonadi::CollectionAttributesSynchronizationJob *sync
+            auto *sync
                 = new Akonadi::CollectionAttributesSynchronizationJob(col);
             sync->setProperty("collectionId", id);
             sync->setProperty("pageToShow", pageToShow);          // note for dialog later
@@ -126,7 +112,7 @@ void ManageShowCollectionProperties::slotCollectionPropertiesContinued(KJob *job
     QPointer<KPIM::ProgressItem> progressItem;
 
     if (job) {
-        Akonadi::CollectionAttributesSynchronizationJob *sync
+        auto *sync
             = qobject_cast<Akonadi::CollectionAttributesSynchronizationJob *>(job);
         Q_ASSERT(sync);
         if (sync->property("collectionId") != mMainWidget->currentCollection().id()) {
@@ -183,7 +169,7 @@ void ManageShowCollectionProperties::slotCollectionPropertiesFinished(KJob *job)
     progressItem->setComplete();
     progressItem->setStatus(i18n("Done"));
 
-    Akonadi::CollectionFetchJob *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    auto *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     Q_ASSERT(fetch);
     if (fetch->collections().isEmpty()) {
         qCWarning(KMAIL_LOG) << "no collection";
