@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "checkindexingjob.h"
@@ -34,8 +21,7 @@ CheckIndexingJob::CheckIndexingJob(Akonadi::Search::PIM::IndexedItems *indexedIt
 }
 
 CheckIndexingJob::~CheckIndexingJob()
-{
-}
+= default;
 
 void CheckIndexingJob::askForNextCheck(quint64 id, bool needToReindex)
 {
@@ -51,8 +37,8 @@ void CheckIndexingJob::setCollection(const Akonadi::Collection &col)
 void CheckIndexingJob::start()
 {
     if (mCollection.isValid()) {
-        Akonadi::CollectionFetchJob *fetch = new Akonadi::CollectionFetchJob(mCollection,
-                                                                             Akonadi::CollectionFetchJob::Base);
+        auto *fetch = new Akonadi::CollectionFetchJob(mCollection,
+                                                      Akonadi::CollectionFetchJob::Base);
         fetch->fetchScope().setIncludeStatistics(true);
         connect(fetch, &KJob::result, this, &CheckIndexingJob::slotCollectionPropertiesFinished);
     } else {
@@ -63,7 +49,7 @@ void CheckIndexingJob::start()
 
 void CheckIndexingJob::slotCollectionPropertiesFinished(KJob *job)
 {
-    Akonadi::CollectionFetchJob *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    auto *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     Q_ASSERT(fetch);
     if (fetch->collections().isEmpty()) {
         qCWarning(KMAIL_LOG) << "No collection fetched";
