@@ -1,22 +1,8 @@
-/* Copyright 2010 Thomas McGuire <mcguire@kde.org>
+/* SPDX-FileCopyrightText: 2010 Thomas McGuire <mcguire@kde.org>
 
-   Copyright 2011-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public License as
-   published by the Free Software Foundation; either version 2 of
-   the License or (at your option) version 3 or any later version
-   accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy
-   defined in Section 14 of version 3 of the license.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-   GNU General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program.  If not, see <https://www.gnu.org/licenses/>.
+   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 #ifndef TAGACTIONMANAGER_H
 #define TAGACTIONMANAGER_H
@@ -25,14 +11,13 @@
 #include "mailcommon/tag.h"
 #include <QMap>
 #include <QVector>
-class KJob;
+#include <AkonadiCore/Item>
 class KActionCollection;
 class KXMLGUIClient;
 class KToggleAction;
 class QAction;
 namespace Akonadi {
 class Item;
-class Monitor;
 class Tag;
 }
 
@@ -103,22 +88,18 @@ Q_SIGNALS:
 
 private:
     Q_DISABLE_COPY(TagActionManager)
-    void finishedTagListing(KJob *job);
     void newTagActionClicked();
     void onSignalMapped(const QString &tag);
-    void onTagAdded(const Akonadi::Tag &);
-    void onTagRemoved(const Akonadi::Tag &);
-    void onTagChanged(const Akonadi::Tag &);
 
     void fillTagList();
     void createTagAction(const MailCommon::Tag::Ptr &tag, bool addToMenu);
     void createTagActions(const QVector<MailCommon::Tag::Ptr> &);
     void checkTags(const QList<qint64> &tags);
-    QList<qint64> checkedTags() const;
+    Q_REQUIRED_RESULT QList<qint64> checkedTags() const;
 
-    KActionCollection *mActionCollection = nullptr;
-    MessageActions *mMessageActions = nullptr;
-    KXMLGUIClient *mGUIClient = nullptr;
+    KActionCollection *const mActionCollection;
+    MessageActions *const mMessageActions;
+    KXMLGUIClient *const mGUIClient;
 
     QAction *mSeparatorMoreAction = nullptr;
     QAction *mSeparatorNewTagAction = nullptr;
@@ -131,13 +112,8 @@ private:
     // The actions of all tags that are in the toolbar
     QList<QAction *> mToolbarActions;
 
-    // A sorted list of all tags
-    QVector<MailCommon::Tag::Ptr> mTags;
-
     // Uri of a newly created tag
     qint64 mNewTagId = -1;
-    bool mTagFetchInProgress = false;
-    Akonadi::Monitor *mMonitor = nullptr;
 };
 }
 
