@@ -1,20 +1,7 @@
 /*
-   Copyright (C) 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
 
-   This program is free software; you can redistribute it and/or
-   modify it under the terms of the GNU General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This program is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   General Public License for more details.
-
-   You should have received a copy of the GNU General Public License
-   along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "undosendcreatejob.h"
@@ -32,8 +19,7 @@ UndoSendCreateJob::UndoSendCreateJob(QObject *parent)
 }
 
 UndoSendCreateJob::~UndoSendCreateJob()
-{
-}
+= default;
 
 bool UndoSendCreateJob::canStart() const
 {
@@ -54,7 +40,7 @@ bool UndoSendCreateJob::start()
     connect(mTimer, &QTimer::timeout, this, &UndoSendCreateJob::slotTimeOut);
     mTimer->setSingleShot(true);
     mTimer->start(mDelay * 1000);
-    mNotification = new KNotification(QStringLiteral("undosend"), nullptr,
+    mNotification = new KNotification(QStringLiteral("undosend"),
                                       KNotification::Persistent);
     mNotification->setText(mSubject);
     mNotification->setActions(QStringList() << i18n("Undo send"));
